execute_script

Function execute_script 

pub async fn execute_script(
    req: ExecuteScriptRequest<'_>,
) -> ExecuteScriptOutcome
Execute a script and capture tracing output for the run record.

Installs a scoped ChrononLogCapture dispatcher for the invoke so info/warn/error events are buffered. Logs are returned on both success and failure (failure also ensures stderr_text includes the error message).